Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(888)

Unified Diff: content/browser/renderer_host/legacy_render_widget_host_win.cc

Issue 2852763002: Added a system caret used for accessibility on Windows. (Closed)
Patch Set: Disabled all tests Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/renderer_host/legacy_render_widget_host_win.h ('k') | ui/accessibility/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/renderer_host/legacy_render_widget_host_win.cc
diff --git a/content/browser/renderer_host/legacy_render_widget_host_win.cc b/content/browser/renderer_host/legacy_render_widget_host_win.cc
index 770362c81171feddebcaf11ca68b3cb24f738f3d..91c4d4f4ebf471934ca5c79d2b0f3c68957d3c78 100644
--- a/content/browser/renderer_host/legacy_render_widget_host_win.cc
+++ b/content/browser/renderer_host/legacy_render_widget_host_win.cc
@@ -17,7 +17,7 @@
#include "content/browser/renderer_host/render_widget_host_impl.h"
#include "content/browser/renderer_host/render_widget_host_view_aura.h"
#include "content/public/common/content_switches.h"
-#include "ui/accessibility/platform/ax_fake_caret_win.h"
+#include "ui/accessibility/platform/ax_system_caret_win.h"
#include "ui/base/view_prop.h"
#include "ui/base/win/internal_constants.h"
#include "ui/base/win/window_event_target.h"
@@ -89,8 +89,8 @@ void LegacyRenderWidgetHostHWND::SetBounds(const gfx::Rect& bounds) {
}
void LegacyRenderWidgetHostHWND::MoveCaretTo(const gfx::Rect& bounds) {
- DCHECK(ax_fake_caret_);
- ax_fake_caret_->MoveCaretTo(bounds);
+ DCHECK(ax_system_caret_);
+ ax_system_caret_->MoveCaretTo(bounds);
}
void LegacyRenderWidgetHostHWND::OnFinalMessage(HWND hwnd) {
@@ -111,10 +111,10 @@ LegacyRenderWidgetHostHWND::LegacyRenderWidgetHostHWND(HWND parent)
Base::Create(parent, rect, L"Chrome Legacy Window",
WS_CHILDWINDOW | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
WS_EX_TRANSPARENT);
// We create the fake caret regardless of accessibility mode since not all
// assistive software that makes use of a fake caret is classified as a screen
// reader, e.g. the built-in Windows Magnifier.
- ax_fake_caret_ = std::make_unique<ui::AXFakeCaretWin>(hwnd());
+ ax_system_caret_ = std::make_unique<ui::AXSystemCaretWin>(hwnd());
}
LegacyRenderWidgetHostHWND::~LegacyRenderWidgetHostHWND() {
@@ -201,11 +201,11 @@ LRESULT LegacyRenderWidgetHostHWND::OnGetObject(UINT message,
}
if (static_cast<DWORD>(OBJID_CARET) == obj_id && host_->HasFocus()) {
- DCHECK(ax_fake_caret_);
- base::win::ScopedComPtr<IAccessible> fake_caret_accessible =
- ax_fake_caret_->GetCaret();
+ DCHECK(ax_system_caret_);
+ base::win::ScopedComPtr<IAccessible> ax_system_caret_accessible =
+ ax_system_caret_->GetCaret();
return LresultFromObject(IID_IAccessible, w_param,
- fake_caret_accessible.Detach());
+ ax_system_caret_accessible.Detach());
}
return static_cast<LRESULT>(0L);
« no previous file with comments | « content/browser/renderer_host/legacy_render_widget_host_win.h ('k') | ui/accessibility/BUILD.gn » ('j') | no next file with comments »
@@ -111,10 +111,10 @@ LegacyRenderWidgetHostHWND::LegacyRenderWidgetHostHWND(HWND parent)
WS_CHILDWINDOW | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
WS_EX_TRANSPARENT);
- // We create the fake caret regardless of accessibility mode since not all
- // assistive software that makes use of a fake caret is classified as a screen
+ // We create a system caret regardless of accessibility mode since not all
+ // assistive software that makes use of a caret is classified as a screen
// reader, e.g. the built-in Windows Magnifier.

Powered by Google App Engine
This is Rietveld 408576698